#ifndef BOOST_SIMD_INCLUDE_CONSTANTS_FOURTHROOTEPS_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_CONSTANTS_FOURTHROOTEPS_HPP_INCLUDED

#include <boost/simd/constant/include/constants/fourthrooteps.hpp>

#endif
